==> apache-seatunnel-2.3.10-src.tar.gz: apache-seatunnel-2.3.10-src/docs/zh/connector-v2/changelog/connector-s3-redshift.md <==
<details><summary> Change Log </summary>

| Change | Commit | Version |
| --- | --- | --- |
|[Feature][S3 File] Make S3 File Connector support multiple table write (#6698)|https://github.com/apache/seatunnel/commit/8f2049b2f1|2.3.6|
|[Refactor][File Connector] Put Multiple Table File API to File Base Module (#6033)|https://github.com/apache/seatunnel/commit/c324d663b4|2.3.4|
|Support using multiple hadoop account (#5903)|https://github.com/apache/seatunnel/commit/d69d88d1aa|2.3.4|
|[Improve][Common] Introduce new error define rule (#5793)|https://github.com/apache/seatunnel/commit/9d1b2582b2|2.3.4|
|[Improve][Connector[File] Optimize files commit order (#5045)|https://github.com/apache/seatunnel/commit/1e18a8c530|2.3.3|
|[BugFix] Fix S3Redshift connector copy file to redshift but file not found bug (#4282)|https://github.com/apache/seatunnel/commit/bcac24ebfc|2.3.1|
|[Fix] [Bug] Fix S3RedShift is not correct with S3 (#4291)|https://github.com/apache/seatunnel/commit/7b72dd95a2|2.3.1|
|Change file type to file_format_type in file source/sink (#4249)|https://github.com/apache/seatunnel/commit/973a2fae3c|2.3.1|
|[Improve][build] Give the maven module a human readable name (#4114)|https://github.com/apache/seatunnel/commit/d7cd601051|2.3.1|
|[Improve][Project] Code format with spotless plugin. (#4101)|https://github.com/apache/seatunnel/commit/a2ab166561|2.3.1|
|[Feature][Connector-V2][File] Optimize filesystem utils (#3749)|https://github.com/apache/seatunnel/commit/ac4e880fb5|2.3.0|
|[Connector][Sink]Support load data to S3 then Copy to Redshift (#3736)|https://github.com/apache/seatunnel/commit/8ef080f200|2.3.0|

</details>

==> apache-seatunnel-2.3.11-src.tar.gz: apache-seatunnel-2.3.11-src/docs/zh/connector-v2/changelog/connector-s3-redshift.md <==
<details><summary> Change Log </summary>

| Change | Commit | Version |
| --- | --- | --- |
|Revert &quot; [improve] update localfile connector config&quot; (#9018)|https://github.com/apache/seatunnel/commit/cdc79e13ad|2.3.10|
| [improve] update localfile connector config (#8765)|https://github.com/apache/seatunnel/commit/def369a85f|2.3.10|
|[Feature][S3 File] Make S3 File Connector support multiple table write (#6698)|https://github.com/apache/seatunnel/commit/8f2049b2f1|2.3.6|
|[Refactor][File Connector] Put Multiple Table File API to File Base Module (#6033)|https://github.com/apache/seatunnel/commit/c324d663b4|2.3.4|
|Support using multiple hadoop account (#5903)|https://github.com/apache/seatunnel/commit/d69d88d1aa|2.3.4|
|[Improve][Common] Introduce new error define rule (#5793)|https://github.com/apache/seatunnel/commit/9d1b2582b2|2.3.4|
|[Improve][Connector[File] Optimize files commit order (#5045)|https://github.com/apache/seatunnel/commit/1e18a8c530|2.3.3|
|[BugFix] Fix S3Redshift connector copy file to redshift but file not found bug (#4282)|https://github.com/apache/seatunnel/commit/bcac24ebfc|2.3.1|
|[Fix] [Bug] Fix S3RedShift is not correct with S3 (#4291)|https://github.com/apache/seatunnel/commit/7b72dd95a2|2.3.1|
|Change file type to file_format_type in file source/sink (#4249)|https://github.com/apache/seatunnel/commit/973a2fae3c|2.3.1|
|[Improve][build] Give the maven module a human readable name (#4114)|https://github.com/apache/seatunnel/commit/d7cd601051|2.3.1|
|[Improve][Project] Code format with spotless plugin. (#4101)|https://github.com/apache/seatunnel/commit/a2ab166561|2.3.1|
|[Feature][Connector-V2][File] Optimize filesystem utils (#3749)|https://github.com/apache/seatunnel/commit/ac4e880fb5|2.3.0|
|[Connector][Sink]Support load data to S3 then Copy to Redshift (#3736)|https://github.com/apache/seatunnel/commit/8ef080f200|2.3.0|

</details>
